@@ -27,10 +27,7 @@ class ScanType(Enum):
     ARP = 1
 
 def is_root():
-    if getuid() == 0:
-        return True #return True if the user is root
-    else:
-        return False
+    return getuid() == 0
 
 # this function is for turning a list of hosts into a single string
 def listToString(s): 
@@ -61,13 +58,13 @@ def TestArp(target, mode=ScanMode.Normal):
 
 #run a port scan on target using nmap
 def PortScan(target, scanspeed=5, mode=ScanMode.Normal, customflags=""):
-    print_colored("\n" + "-" * 60, colors.green)
+    print_colored("\n" + "─" * 60, colors.green)
     print_colored(("Running a portscan on host " + str(target) + "...").center(60), colors.green)
-    print_colored("-" * 60 + "\n", colors.green)
+    print_colored("─" * 60 + "\n", colors.green)
 
-    WriteToFile("\n" + "-" * 60)
+    WriteToFile("\n" + "─" * 60)
     WriteToFile(("Portscan results for host " + str(target) + ".").center(60))
-    WriteToFile("-" * 60 + "\n")
+    WriteToFile("─" * 60 + "\n")
 
     nm = PortScanner()
 
@@ -99,9 +96,9 @@ def CreateNoise(target):
         pass
 
 def NoiseScan(target, scantype=ScanType.ARP, timeout=None):
-    print_colored("\n" + "-" * 60, colors.green)
+    print_colored("\n" + "─" * 60, colors.green)
     print_colored("Creating noise...".center(60), colors.green)
-    print_colored("-" * 60 + "\n", colors.green)
+    print_colored("─" * 60 + "\n", colors.green)
     WriteToFile("\nCreating noise...")
 
     if scantype == ScanType.Ping:
@@ -149,8 +146,8 @@ def NoiseScan(target, scantype=ScanType.ARP, timeout=None):
         exit(0)
 
 def DiscoverHosts(target, scantype=ScanType.ARP, scanspeed=3, mode=ScanMode.Normal):
-    print_colored("\n" + "-" * 60, colors.green)
-    WriteToFile("\n" + "-" * 60)
+    print_colored("\n" + "─" * 60, colors.green)
+    WriteToFile("\n" + "─" * 60)
     if type(target) is list:
         print_colored(("Scanning " + str(len(target)) + " target(s) using " + str(scantype.name) + " scan...").center(60), colors.green)
         WriteToFile("\nScanning %d hosts using %s scan..." % (len(target), str(scantype.name)))
@@ -158,8 +155,8 @@ def DiscoverHosts(target, scantype=ScanType.ARP, scanspeed=3, mode=ScanMode.Norm
         print_colored(("Scanning " + target + " using " + str(scantype.name) + " scan...").center(60), colors.green)
         WriteToFile(("Scanning " + target + " using " + str(scantype.name) + " scan...").center(60))
     
-    print_colored("-" * 60 + "\n", colors.green)
-    WriteToFile("-" * 60 + "\n")
+    print_colored("─" * 60 + "\n", colors.green)
+    WriteToFile("─" * 60 + "\n")
 
     if scantype == ScanType.Ping:
         OnlineHosts = TestPing(target, mode)
@@ -222,14 +219,14 @@ def AnalyseScanResults(nm, target=None):
         (
             bcolors.yellow + "MAC Address : " + bcolors.endc + "{0:20}" +
             bcolors.yellow + " Vendor : " + bcolors.endc + "{1:30}"
-        ).format(mac , vendor)
+        ).format(mac , vendor[:30])
     )
 
     WriteToFile(
         (
             "MAC Address : {0:20}" +
             " Vendor : {1:30}\n"
-        ).format(mac, vendor)
+        ).format(mac, vendor[:30])
     )
 
     print(
@@ -237,7 +234,7 @@ def AnalyseScanResults(nm, target=None):
             bcolors.yellow + "OS : " + bcolors.endc + "{0:20}" +
             bcolors.yellow + " Accuracy : " + bcolors.endc + "{1:5}" +
             bcolors.yellow + " Type : " + bcolors.endc + "{2:20}"
-        ).format(os , accuracy , ostype)
+        ).format(os[:20], accuracy , ostype[:20])
     )
 
     WriteToFile(
@@ -245,15 +242,21 @@ def AnalyseScanResults(nm, target=None):
             "OS : {0:20}" +
             " Accuracy : {1:5}" +
             " Type : {2:20}"
-        ).format(os , accuracy , ostype)
+        ).format(os[:20], accuracy , ostype[:20])
     )
 
     print("\n")
     WriteToFile("\n")
 
-    if nm[target]['status']['reason'] == 'localhost-response' or nm[target]['status']['reason'] == 'user-set':
-        print_colored('Target ' + str(target) + ' seems to be us.', colors.underline)
-        WriteToFile('Target ' + str(target) + ' seems to be us.\n')
+    reason = nm[target]['status']['reason']
+
+    if is_root():
+        if reason == 'localhost-response' or reason == 'user-set':
+            print_colored('Target ' + str(target) + ' seems to be us.', colors.underline)
+            WriteToFile('Target ' + str(target) + ' seems to be us.\n')
+    # we cant detect if the host is us or not, if we are not root
+    # we could get our ip address and compare them but i think it's not quite necessary
+
     if len(nm[target].all_protocols()) == 0:
         print_colored("Target " + str(target) + " seems to have no open ports.", colors.red)
         WriteToFile("Target " + str(target) + " seems to have no open ports.")
@@ -287,7 +290,7 @@ def AnalyseScanResults(nm, target=None):
                 bcolors.cyan + " Service : " + bcolors.endc + "{2:15}" +
                 bcolors.cyan + " Product : " + bcolors.endc + "{3:20}" +
                 bcolors.cyan + " Version : " + bcolors.endc + "{4:15}"
-            ).format(str(port), state, service, product, version)
+            ).format(str(port), state, service[:15], product[:20], version[:15])
         )
 
         WriteToFile(
@@ -297,7 +300,7 @@ def AnalyseScanResults(nm, target=None):
                 " Service : {2:20}" +
                 " Product : {3:20}" +
                 " Version : {4:20}"
-            ).format(str(port), state, service, product, version)
+            ).format(str(port), state, service[:15], product[:20], version[:15])
         )
 
         if state == 'open':
