@@ -3,6 +3,12 @@ from modules.nvdlib.nvdlib import searchCPE, searchCVE, getCVE
 from textwrap import wrap
 from os import get_terminal_size
 from modules.outfile import WriteToFile
+from dataclasses import dataclass
+
+@dataclass
+class Vuln:
+    Software : str
+    CVEs : list
 
 #generate keywords to search for from the information gathered from the target
 def GenerateKeywords(HostArray):
@@ -50,14 +56,17 @@ def SearchKeyword(keyword, apiKey=None):
             ApiResponseCPE = searchCPE(keyword=keyword, key=apiKey)
             ApiResponseCVE = searchCVE(keyword=keyword, key=apiKey)
     except KeyboardInterrupt:
+        print(" " * 100, end="\r")
         print_colored("Skipping vulnerability detection for keyword " + keyword, colors.red)
         WriteToFile("Skipped vulnerability detection for keyword " + keyword)
         return '', []
     except LookupError:
+        print(" " * 100, end="\r")
         print_colored("NIST API returned an invalid response for keyword " + keyword, colors.red)
         WriteToFile("NIST API returned an invalid response for keyword " + keyword)
         return '', []
     except Exception as e:
+        print(" " * 100, end="\r")
         print_colored("Error: " + str(e), colors.red)
         WriteToFile("Error: " + str(e))
         return '', []
@@ -81,15 +90,16 @@ def SearchKeyword(keyword, apiKey=None):
     return CPETitle, ApiResponseCVE
 
 def SearchSploits(HostArray, apiKey=None):
+    VulnsArray = []
     target = str(HostArray[0][0])
 
-    print_colored("\n" + "-" * 60, colors.red)
+    print_colored("\n" + "─" * 60, colors.red)
     print_colored(("Possible vulnerabilities for " + target).center(60), colors.red)
-    print_colored("-" * 60 + "\n", colors.red)
+    print_colored("─" * 60 + "\n", colors.red)
 
-    WriteToFile("\n" + "-" * 60)
+    WriteToFile("\n" + "─" * 60)
     WriteToFile(("Possible vulnerabilities for " + target).center(60))
-    WriteToFile("-" * 60 + "\n")
+    WriteToFile("─" * 60 + "\n")
 
     keywords = GenerateKeywords(HostArray)
 
@@ -106,16 +116,20 @@ def SearchSploits(HostArray, apiKey=None):
         #search the NIST vulnerabilities database for the generated keywords
         CPETitle, ApiResponseCVE = SearchKeyword(keyword, apiKey)
 
-        #if the keyword is found in the NVD database, print the title of the vulnerability
+        #if the keyword is found in the NVD database, print the title of the vulnerable software
         if CPETitle != '':
-            print("\n\n┌─" + bcolors.yellow + "[ " + CPETitle + " ]" + bcolors.endc)
-            WriteToFile("\n\n┌─[ %s ]" % CPETitle)
+            Title = CPETitle
         elif CPETitle == '' and len(ApiResponseCVE) != 0:
-            print("\n\n┌─" + bcolors.yellow + "[ " + keyword + " ]" + bcolors.endc)
-            WriteToFile("\n\n┌─[ %s ]" % keyword)
+            Title = keyword
         elif CPETitle == '' and len(ApiResponseCVE) == 0:
             continue
 
+        # create a Vuln object
+        VulnObject = Vuln(Software=Title, CVEs=[])
+
+        print("\n\n┌─" + bcolors.yellow + "[ " + Title + " ]" + bcolors.endc)
+        WriteToFile("\n\n┌─[ %s ]" % Title)
+
         for CVE in ApiResponseCVE:
             print("│\n├─────┤ " + bcolors.red + str(CVE.id) + bcolors.endc + "\n│")
             WriteToFile("│\n├─────┤ " + str(CVE.id) + "\n│")
@@ -148,4 +162,12 @@ def SearchSploits(HostArray, apiKey=None):
             WriteToFile("│\t\t" + "Exploitability : " + exploitability)
             
             print("│\t\t" + bcolors.cyan + "Details : " + bcolors.endc + details)
-            WriteToFile("│\t\t" + "Details : " + details)
\ No newline at end of file
+            WriteToFile("│\t\t" + "Details : " + details)
+
+            VulnObject.CVEs.append(str(CVE.id))
+
+        VulnsArray.append(VulnObject)
+        print(" " * 100, end="\r") #clear the line
+        print("└" + "─" * 59)
+
+    return VulnsArray
\ No newline at end of file
